@@ -40,9 +40,8 @@ inline Tp::ChannelClassSpecList channelClassList()
 }
 
 
-TelepathyChatUi::TelepathyChatUi(const Tp::AccountManagerPtr &accountManager)
-    : KTp::TelepathyHandlerApplication(true, -1, -1), AbstractClientHandler(channelClassList()),
-      m_accountManager(accountManager)
+TelepathyChatUi::TelepathyChatUi()
+    : KTp::TelepathyHandlerApplication(true, -1, -1), AbstractClientHandler(channelClassList())
 {
     kDebug();
     ChatWindow *window = createWindow();
@@ -182,8 +181,3 @@ bool TelepathyChatUi::bypassApproval() const
     return false;
 }
 
-Tp::AccountManagerPtr TelepathyChatUi::accountManager() const
-{
-    return m_accountManager;
-}
-
