@@ -28,13 +28,14 @@ public:
 };
 
 EmoticonFilter::EmoticonFilter(QObject *parent, const QVariantList &)
-    : AbstractMessageFilter(parent),
+    : KTp::AbstractMessageFilter(parent),
       d(new Private)
 {
 }
 
-void EmoticonFilter::filterMessage(Message& message)
+void EmoticonFilter::filterMessage(KTp::Message &message, const KTp::MessageContext &context)
 {
+    Q_UNUSED(context)
     message.setMainMessagePart(d->emoticons.theme().parseEmoticons(message.mainMessagePart()));
 }
 
@@ -46,4 +47,4 @@ EmoticonFilter::~EmoticonFilter()
 K_PLUGIN_FACTORY(MessageFilterFactory, registerPlugin<EmoticonFilter>();)
 K_EXPORT_PLUGIN(MessageFilterFactory("ktptextui_message_filter_emoticons"))
 
-#include "moc_emoticon-filter.cpp"
\ No newline at end of file
+#include "moc_emoticon-filter.cpp"
